@@ -6,6 +6,8 @@ from typing import Optional, List, Union
 
 import adafruit_ads1x15.ads1115 as ADS
 from adafruit_ads1x15.analog_in import AnalogIn
+from adafruit_max31865 import MAX31865
+
 from filterpy.kalman import KalmanFilter
 from filterpy.common import Q_discrete_white_noise
 
@@ -50,6 +52,11 @@ class CalPtOrp:
     V: float
     ORP: float
 
+@dataclass
+class CalPtT:
+    V: float
+    T: float  # Temp in C
+
 
 @dataclass
 class PhSensor:
@@ -247,6 +254,63 @@ class OrpSensor:
         self.cal = CalPtOrp(0.4, 400.0)
 
 
+class RtdType(Enum):
+    PT100 = auto()
+    PT1000 = auto()
+
+
+class RtdWires(Enum):
+    TWO = auto()
+    THREE = auto()
+    FOUR = auto()
+
+
+@dataclass
+class Rtd:
+    sensor: MAX31865
+    type_: RtdType
+    wires: RtdWires
+    cal: CalPtT
+
+    def __init__(self, spi, cs, type_: RtdType, wires_: RtdWires):
+        if type_ == RtdType.PT100:
+            rtd_nominal = 100
+            ref_resistor = 300
+        elif type_ == RtdType.PT1000:
+            rtd_nominal = 1_000
+            ref_resistor = 3_000
+        else:
+            raise TypeError("Invalid RtdType: Must be `RtdType.PT100`, or `RtdType.PT1000`.")
+
+        if wires_ == RtdWires.TWO:
+            wires = 2
+        elif wires_ == RtdWires.THREE:
+            wires = 3
+        elif wires_ == RtdWires.FOUR:
+            wires = 4
+        else:
+            raise TypeError("Invalid RtdWires: Must be `RtdWires.TWO`, `RtdWires.THREE`, or `RtdWires.FOUR`.")
+
+        self.sensor = MAX31865(
+            spi,
+            cs,
+            wires=wires,
+            rtd_nominal=rtd_nominal,
+            ref_resistor=ref_resistor
+        )
+
+    def read(self) -> float:
+        """Read measured temperature"""
+        return self.sensor.temperature
+
+    def read_resistance(self) -> float:
+        """Read measured resistance of the RTD"""
+        return self.sensor.resistance
+
+    def calibrate(self) -> None:
+        pass
+
+
 @dataclass
 class Readings:
     # todo: Should these (And the readings in general) be Optional[float] to deal
@@ -256,40 +320,40 @@ class Readings:
     ec: float
     ORP: float
 
-
-@dataclass
-class WaterMonitor:
-    """We use this to pull data from the Water Monitor to an external program over I2C.
-    It interacts directly with the ADCs, and has no interaction to the Water Monitor's MCU."""
-    ph_temp: PhSensor  # at 0x48. Inludes the temp sensor at input A3.
-    orp_ec: OrpSensor  # at 0x49. Inlucdes the ec sensor at input A3.
-
-    def __init__(self, i2c, dt: float):
-        self.ph_temp = PhSensor(i2c, dt)
-        self.orp_ec = OrpSensor(i2c, dt, address=0x49)
-
-    def read_all(self) -> Readings:
-        """Read all sensors."""
-        T = self.ph_temp.read_temp_pt100()
-        pH = self.ph_temp.read(OffBoard(T))
-        ORP = self.orp_ec.read()
-        ec = self.orp_ec.read_ec(OffBoard(T))
-
-        return Readings(pH, T, ec, ORP)
-
-    def read_ph(self) -> float:
-        t = OffBoard(self.ph_temp.read_temp_pt100())
-        return self.ph_temp.read(t)
-
-    def read_temp(self) -> float:
-        return self.ph_temp.read_temp_pt100()
-
-    def read_orp(self) -> float:
-        return self.orp_ec.read()
-
-    def read_ec(self) -> float:
-        t = OffBoard(self.ph_temp.read_temp_pt100())
-        return sself.orp_ec.read_ec(t)
+#
+# @dataclass
+# class WaterMonitor:
+#     """We use this to pull data from the Water Monitor to an external program over I2C.
+#     It interacts directly with the ADCs, and has no interaction to the Water Monitor's MCU."""
+#     ph_temp: PhSensor  # at 0x48. Inludes the temp sensor at input A3.
+#     orp_ec: OrpSensor  # at 0x49. Inlucdes the ec sensor at input A3.
+#
+#     def __init__(self, i2c, dt: float):
+#         self.ph_temp = PhSensor(i2c, dt)
+#         self.orp_ec = OrpSensor(i2c, dt, address=0x49)
+#
+#     def read_all(self) -> Readings:
+#         """Read all sensors."""
+#         T = self.ph_temp.read_temp_pt100()
+#         pH = self.ph_temp.read(OffBoard(T))
+#         ORP = self.orp_ec.read()
+#         ec = self.orp_ec.read_ec(OffBoard(T))
+#
+#         return Readings(pH, T, ec, ORP)
+#
+#     def read_ph(self) -> float:
+#         t = OffBoard(self.ph_temp.read_temp_pt100())
+#         return self.ph_temp.read(t)
+#
+#     def read_temp(self) -> float:
+#         return self.ph_temp.read_temp_pt100()
+#
+#     def read_orp(self) -> float:
+#         return self.orp_ec.read()
+#
+#     def read_ec(self) -> float:
+#         t = OffBoard(self.ph_temp.read_temp_pt100())
+#         return sself.orp_ec.read_ec(t)
 
 
 def lg(
